@@ -25,8 +25,7 @@ class TestSecurityHeaders:
         client = Client()
         response = client.request('GET', path)
         assert response.get_header("X-Frame-Options") is None  # changed from: == "SAMEORIGIN"
-        sso = 'https://%(ucs/server/sso/fqdn)s/ http://%(ucs/server/sso/fqdn)s/ https://%(keycloak/server/sso/fqdn)s/ http://%(keycloak/server/sso/fqdn)s/' % defaultdict(lambda: '', ucr)
-        sso = sso.replace('http:///', '').replace('https:///', '').strip()
+        sso = '%(ucs/server/sso/uri)s/' % defaultdict(lambda: '', ucr)
         assert response.get_header("Content-Security-Policy") == "default-src 'self' 'unsafe-inline' 'unsafe-eval' %s  https://www.piwik.univention.de/ ; frame-ancestors 'self';" % sso
 
         assert response.get_header("X-Permitted-Cross-Domain-Policies") == "master-only"
@@ -48,9 +47,9 @@ class TestSecurityHeaders:
         if path == '/languages.json':
             assert response.get_header("Content-Security-Policy") == "frame-ancestors 'none';"
         else:
-            sso = 'https://%(ucs/server/sso/fqdn)s/ http://%(ucs/server/sso/fqdn)s/ https://%(keycloak/server/sso/fqdn)s/ http://%(keycloak/server/sso/fqdn)s/' % defaultdict(lambda: '', ucr)
+            sso = '%(ucs/server/sso/uri)s/' % defaultdict(lambda: '', ucr)
             if 'portal' in path:
-                sso = 'https://%(ucs/server/sso/fqdn)s/ http://%(ucs/server/sso/fqdn)s/' % defaultdict(lambda: '', ucr)
+                sso = '%(ucs/server/sso/uri)s/' % defaultdict(lambda: '', ucr)
             sso = sso.replace('http:///', '').replace('https:///', '').strip()
             expected = "frame-ancestors 'self' %s;" % sso
             assert expected in response.get_header("Content-Security-Policy")
