@@ -13,11 +13,11 @@
 ## bugs: [57279]
 
 import subprocess
+from collections.abc import Iterator
 from contextlib import contextmanager, suppress
 from pathlib import Path
 from shlex import quote
 from tempfile import mkdtemp
-from typing import Iterator
 
 import ldap
 from retrying import retry
