@@ -91,9 +91,9 @@ OLD_EXPECTED_EXECUTIONS = [
         'displayName': 'OTP Form',
         'configurable': False,
         'providerId': 'auth-otp-form',
-        'level': 2,
-        'index': 1,
-        'priority': 20,
+        'level': 3,
+        'index': 2,
+        'priority': 40,
     },
     {
         'requirement': 'REQUIRED',
@@ -231,24 +231,33 @@ EXPECTED_EXECUTIONS = [
         'configurable': False,
         'providerId': 'auth-otp-form',
         'level': 2,
+        'index': 2,
+        'priority': 30,
+    },
+    {
+        'configurable': True,
+        'displayName': 'Condition - credential',
         'index': 1,
+        'level': 2,
         'priority': 20,
+        'providerId': 'conditional-credential',
+        'requirement': 'REQUIRED',
     },
     {
         'configurable': False,
         'displayName': 'WebAuthn Authenticator',
-        'index': 2,
+        'index': 3,
         'level': 2,
-        'priority': 30,
+        'priority': 40,
         'providerId': 'webauthn-authenticator',
         'requirement': 'DISABLED',
     },
     {
         'configurable': False,
         'displayName': 'Recovery Authentication Code Form',
-        'index': 3,
+        'index': 4,
         'level': 2,
-        'priority': 40,
+        'priority': 50,
         'providerId': 'auth-recovery-authn-code-form',
         'requirement': 'DISABLED',
     },
